/**
 * Deeply picks the specified dot-separated keys from the object.
 *
 * e.g.
 * ```
 * interface Foo {
 *  a: {
 *    b: {
 *      c: any
 *    },
 *    d: any
 *  }
 * }
 *
 * DeepPick<Foo, 'a.b'> // { a: { b: any } }
 * ```
 *
 */
export type DeepPick<T, K> = K extends keyof T ? Pick<T, K> : K extends `${infer Key}.${infer Rest}` ? Key extends keyof T ? {
    [P in Key]: DeepPick<T[Key], Rest>;
} : never : never;
//# sourceMappingURL=DeepPick.types.d.ts.map